==> ukui-tablet-desktop_4.0.0.0.orig.tar.gz: ukui-tablet-desktop-4.0.0.0/tablet-desktop/translations/ukui-tablet-desktop_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AppContainer</name>
    <message>
        <location filename="../ui/qml/AppContainer.qml" line="9"/>
        <source>container</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AppIconContainer</name>
    <message>
        <location filename="../ui/qml/AppIconContainer.qml" line="184"/>
        <source>Widget is Null</source>
        <translation>小插件内容为空</translation>
    </message>
    <message>
        <location filename="../ui/qml/AppIconContainer.qml" line="187"/>
        <source>Loading widget Error</source>
        <translation>加载小插件失败</translation>
    </message>
</context>
<context>
    <name>GroupZoomDialog</name>
    <message>
        <location filename="../ui/qml/GroupZoomDialog.qml" line="13"/>
        <source>group</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>KQuickItemView</name>
    <message>
        <location filename="../kgridview/5.12/kquickitemview.cpp" line="2273"/>
        <location filename="../kgridview/5.15/kquickitemview.cpp" line="2365"/>
        <source>Delegate must be of Item type</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="65"/>
        <source>Mobile</source>
        <translation>移动</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="66"/>
        <source>Internet</source>
        <translation>网络</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="67"/>
        <source>Social</source>
        <translation>社交</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="68"/>
        <source>Video</source>
        <translation>视频</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="69"/>
        <source>Development</source>
        <translation>开发</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="70"/>
        <source>Image</source>
        <translation>图像</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="71"/>
        <source>Game</source>
        <translation>游戏</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="72"/>
        <source>Office</source>
        <translation>办公</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="73"/>
        <source>Education</source>
        <translation>教育</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="74"/>
        <source>System</source>
        <translation>系统</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="75"/>
        <source>Safe</source>
        <translation>安全</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="76"/>
        <source>Others</source>
        <translation>其他</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="77"/>
        <source>Group</source>
        <translation>应用组</translation>
    </message>
</context>
<context>
    <name>UKUI::TabletDesktopBackend</name>
    <message>
        <source>Mobile</source>
        <translation type="vanished">移动</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="vanished">网络</translation>
    </message>
    <message>
        <source>Social</source>
        <translation type="vanished">社交</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">视频</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">开发</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">游戏</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">办公</translation>
    </message>
    <message>
        <source>Education</source>
        <translation type="vanished">教育</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">系统</translation>
    </message>
    <message>
        <source>Safe</source>
        <translation type="vanished">安全</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="vanished">其他</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="vanished">应用组</translation>
    </message>
</context>
<context>
    <name>UninstallAppDialog</name>
    <message>
        <source>Remove </source>
        <translation type="vanished">确认卸载</translation>
    </message>
    <message>
        <source>?</source>
        <translation type="vanished">？</translation>
    </message>
    <message>
        <location filename="../ui/qml/UninstallAppDialog.qml" line="41"/>
        <source>Remove &quot;%1&quot;?</source>
        <translation>确认卸载“%1”？</translation>
    </message>
    <message>
        <location filename="../ui/qml/UninstallAppDialog.qml" line="60"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../ui/qml/UninstallAppDialog.qml" line="69"/>
        <source>OK</source>
        <translation>确认</translation>
    </message>
</context>
</TS>

==> ukui-tablet-desktop_4.10.0.0.orig.tar.gz: ukui-tablet-desktop-4.10.0.0/tablet-desktop/translations/ukui-tablet-desktop_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AddApp</name>
    <message>
        <source>取消</source>
        <translation type="vanished">Cancel</translation>
    </message>
    <message>
        <source>确定</source>
        <translation type="vanished">OK</translation>
    </message>
    <message>
        <location filename="../ui/qml/AddApp.qml" line="351"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../ui/qml/AddApp.qml" line="374"/>
        <source>OK</source>
        <translation>确认</translation>
    </message>
</context>
<context>
    <name>AppContainer</name>
    <message>
        <location filename="../ui/qml/AppContainer.qml" line="10"/>
        <source>container</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AppIconContainer</name>
    <message>
        <location filename="../ui/qml/AppIconContainer.qml" line="185"/>
        <source>Widget is Null</source>
        <translation>小插件内容为空</translation>
    </message>
    <message>
        <location filename="../ui/qml/AppIconContainer.qml" line="188"/>
        <source>Loading widget Error</source>
        <translation>加载小插件失败</translation>
    </message>
</context>
<context>
    <name>KQuickItemView</name>
    <message>
        <location filename="../kgridview/5.12/kquickitemview.cpp" line="2273"/>
        <location filename="../kgridview/5.15/kquickitemview.cpp" line="2365"/>
        <source>Delegate must be of Item type</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ModelManagerPrivate</name>
    <message>
        <location filename="../core/modelmanagerprivate.cpp" line="254"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="65"/>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="66"/>
        <source>Mobile</source>
        <translation>移动</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="67"/>
        <source>Internet</source>
        <translation>网络</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="68"/>
        <source>Social</source>
        <translation>社交</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="69"/>
        <source>Video</source>
        <translation>视频</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="70"/>
        <source>Development</source>
        <translation>开发</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="71"/>
        <source>Image</source>
        <translation>图像</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="72"/>
        <source>Game</source>
        <translation>游戏</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="73"/>
        <source>Office</source>
        <translation>办公</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="74"/>
        <source>Education</source>
        <translation>教育</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="75"/>
        <source>System</source>
        <translation>系统</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="76"/>
        <source>Safe</source>
        <translation>安全</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="77"/>
        <source>Others</source>
        <translation>其他</translation>
    </message>
    <message>
        <location filename="../../tablet-desktop-backend/utils.cpp" line="78"/>
        <source>Group</source>
        <translation>应用组</translation>
    </message>
    <message>
        <location filename="../base/launcheritemhelper.cpp" line="62"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
</context>
<context>
    <name>UKUI::TabletDesktopBackend</name>
    <message>
        <source>Mobile</source>
        <translation type="vanished">移动</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="vanished">网络</translation>
    </message>
    <message>
        <source>Social</source>
        <translation type="vanished">社交</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">视频</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">开发</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">游戏</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">办公</translation>
    </message>
    <message>
        <source>Education</source>
        <translation type="vanished">教育</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">系统</translation>
    </message>
    <message>
        <source>Safe</source>
        <translation type="vanished">安全</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="vanished">其他</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="vanished">应用组</translation>
    </message>
</context>
<context>
    <name>UninstallAppDialog</name>
    <message>
        <source>Remove </source>
        <translation type="vanished">确认卸载</translation>
    </message>
    <message>
        <source>?</source>
        <translation type="vanished">？</translation>
    </message>
    <message>
        <location filename="../ui/qml/UninstallAppDialog.qml" line="41"/>
        <source>Remove &quot;%1&quot;?</source>
        <translation>确认卸载“%1”？</translation>
    </message>
    <message>
        <location filename="../ui/qml/UninstallAppDialog.qml" line="60"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../ui/qml/UninstallAppDialog.qml" line="69"/>
        <source>OK</source>
        <translation>确认</translation>
    </message>
</context>
</TS>
